@@ -14,8 +14,8 @@ def add_encrypted_settings(module_globals=None, settings_file=None, key=None):
     module_globals.update(json.loads(get_decrypted_file(settings_file, key)))
 
 
-def get_credentials(credential_name):
+def get_credentials(credential_name, key=None):
     credential_file = settings.CREDENTIAL_FILES.get(credential_name)
     if not credential_name:
         raise MissingCredentials(f"Cannot find '{credential_name}' in CREDENTIAL_FILES")
-    return get_decrypted_file(os.path.join(settings.CREDENTIAL_FOLDER, credential_file))
+    return get_decrypted_file(os.path.join(settings.CREDENTIAL_FOLDER, credential_file), key)
